import * as d3 from 'd3';

export const main = (container) => {
  // Data and accessors
  const data = [
    {
      label: 'Recommended',
      value: 60,
    },
    {
      label: 'You',
      value: 20,
    },
    {
      label: 'Peers',
      value: 40,
    },
  ];
  const xAccessor = (d) => d.label;
  const yAccessor = (d) => d.value;

  // Chart dimensions
  const width = container.clientWidth;
  const height = container.clientHeight;

  const dimensions = {
    width,
    height,
    marginTop: 30,
    marginRight: 30,
    marginBottom: 30,
    marginLeft: 30,
  };

  dimensions.boundedWidth =
    dimensions.width -
    dimensions.marginLeft -
    dimensions.marginRight;
  dimensions.boundedHeight =
    dimensions.height -
    dimensions.marginTop -
    dimensions.marginBottom;

  // svg and bound
  const svg = d3
    .select(container)
    .selectAll('svg')
    .data([null])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .style('background', '#F0FFF4');

  const bound = svg
    .append('g')
    .style(
      'transform',
      `translate(${dimensions.marginLeft}px, ${dimensions.marginTop}px)`,
    );

  // Scales
  const xScale = d3
    .scaleBand()
    .domain(d3.extent(data, xAccessor))
    .range([0, dimensions.boundedWidth]);

  const yScale = d3
    .scaleLinear()
    .domain(d3.extent(data, yAccessor))
    .range([dimensions.boundedHeight, 0]);

  const colorScale = d3
    .scaleOrdinal()
    .domain(d3.extent(data, xAccessor))
    .range(d3.schemeCategory10);

  // Add xAxis
  const xAxisGenerator = d3.axisBottom(xScale);
  const yAxisGenerator = d3.axisLeft(yScale);

  const xAxis = bound
    .append('g')
    .style(
      'transform',
      `translateY(${dimensions.boundedHeight}px)`,
    )
    .call(xAxisGenerator);

  const yAxis = bound.append('g').call(yAxisGenerator);

  // Draw Bars
  bound.selectAll('.bar')
    .data(data)
    .join('rect')
      .attr('class', 'bar')
      .attr('x', d => xScale(d.label))
      .attr('y', d => yScale(d.value))
      .attr()
};



















